@@ -59,7 +59,6 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
     name <- NULL
     nid <- NULL
     noheader <- NULL
-    pastes <- NULL
     scope <- NULL
 
 ###  Section end: Dummy variables, only not to get NOTE's in pacakge checks ####
@@ -93,8 +92,9 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
                                  keep.comments=FALSE,keep.empty=FALSE,
                                  as.one=FALSE, simplify=FALSE)
     if(length(lines.table)==0) {
-        messageWrap("No TABLE sections found in control stream. Please inspect the control stream.",
-                    fun.msg=stop)
+        if(!quiet) messageWrap("No TABLE sections found in control stream. Returning NULL",
+                               fun.msg=message)
+        return(NULL)
     }
     
     tab.files <- lapply(lines.table,function(x) {
@@ -117,7 +117,7 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
 
     meta.tabs.strange <- meta[(firstonly+lastonly+firstlastonly)>1]
     if(nrow(meta.tabs.strange)){
-        warning("Table(s) seems to have more than one of the firstonly, lastonly and firstlastonly options. Does this make sense? Look at table(s): ",pastes(meta.tabs.strange[,name],collapse=", "))
+        warning("Table(s) seems to have more than one of the firstonly, lastonly and firstlastonly options. Does this make sense? Look at table(s): ",paste(meta.tabs.strange[,name],collapse=", "))
     }
     tables <- list()
 
