@@ -3,6 +3,9 @@
 ## load_all()
 
 context("NMscanData")
+library(data.table)
+data.table::setDTthreads(1)
+
 ## NMdata_filepath <- function(...) {
 ##     system.file(..., package = "NMdata")
 ## }
@@ -62,7 +65,7 @@ test_that("Modifications to column names in $INPUT",{
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr002.lst")
     file.lst <- "testData/nonmem/xgxr002.lst"
 
-    res1 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE)
+    res1 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, quiet=T)
 
     res <- list(
         NMinfo(res1,"input.colnames"),
@@ -83,8 +86,8 @@ test_that("No translation of column names in $INPUT",{
     
     file.lst <- "testData/nonmem/xgxr002.lst"
 
-    res1 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, translate.input = T)
-    res2 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, translate.input = F)
+    res1 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, translate.input = T, quiet=T)
+    res2 <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, translate.input = F, quiet=T)
 
     dt.cnames <- data.table(colnames(res1),colnames(res2))
     expect_equal_to_reference(dt.cnames,fileRef,version=2)
@@ -95,13 +98,13 @@ test_that("No translation of column names in $INPUT",{
 test_that("Multiple output table formats",{
 
     NMdataConf(reset=TRUE)
-    fileRef <- "testReference/NMscanData3.rds"
+    fileRef <- "testReference/NMscanData_03.rds"
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr003.lst")
     file.lst <- "testData/nonmem/xgxr003.lst"
 
 
     ## res <- NMscanData(file=file.lst)
-    res <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE)
+    res <- NMscanData(file=file.lst, check.time = FALSE, merge.by.row=FALSE, quiet=T)
     fix.time(res)
 
     
@@ -125,7 +128,7 @@ test_that("Interpret IGNORE statement",{
     ## res <- NMscanData(file=file.lst)
     ## res <- NMscanData(file=file.lst)
 
-    res <- NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE)
+    res <- NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE, quiet=T)
     fix.time(res)
     ## names(res$row)
     
@@ -146,8 +149,8 @@ test_that("List of ACCEPT statements and vs separate statements",{
 
     NMreadSection(file1.lst,section="PROBLEM")
     NMreadSection(file2.lst,section="PROBLEM")
-    res1 <- NMscanData(file=file1.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE)
-    res2 <- NMscanData(file=file2.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE) 
+    res1 <- NMscanData(file=file1.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE, quiet=T)
+    res2 <- NMscanData(file=file2.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE, quiet=T) 
     setattr(res1,"NMdata",NULL)
     setattr(res2,"NMdata",NULL)
     expect_identical(res1,res2)
@@ -165,8 +168,8 @@ test_that("merge by filters or not",{
     ## NMreadSection(file1.lst,section="PROBLEM")
     ## NMreadSection(file2.lst,section="PROBLEM")
 
-    res1 <- NMscanData(file=file1.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE)
-    res2 <- NMscanData(file=file2.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE)
+    res1 <- NMscanData(file=file1.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE, quiet=T)
+    res2 <- NMscanData(file=file2.lst,merge.by.row=FALSE,col.model=NULL,check.time = FALSE, quiet=T)
     setnames(res2,"EFF0","eff0",skip_absent=T)
     setcolorder(res1,colnames(res2))
 
@@ -192,7 +195,7 @@ test_that("Only a firstonly without ID but with ROW",{
 ### This should work because ROW is in firstonly table.
     NMdataConf(reset=TRUE)
     ## NMdataConf(as.fun="data.table")
-    fileRef <- "testReference/NMscanData11.rds"
+    fileRef <- "testReference/NMscanData_11.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr011.lst")
     file.lst <- "testData/nonmem/xgxr011.lst"
@@ -205,14 +208,14 @@ test_that("Only a firstonly without ID but with ROW",{
 ### impossible with filters at the moment. Cannot be implemented because id level cannot be merged onto row level input.
     expect_error(
         expect_warning(
-            NMscanData(file=file.lst,merge.by.row=FALSE,col.row="ROW",check.time = FALSE)
+            NMscanData(file=file.lst,merge.by.row=FALSE,col.row="ROW",check.time = FALSE, quiet=T)
         )
     )
 
     ## merge.by.row should be able to merge. 
     res <-
         expect_warning(
-            NMscanData(file=file.lst,merge.by.row=TRUE,col.row="ROW",check.time = FALSE)
+            NMscanData(file=file.lst,merge.by.row=TRUE,col.row="ROW",check.time = FALSE, quiet=T)
         )
     fix.time(res)
     expect_equal_to_reference(res,fileRef,version=2)
@@ -241,7 +244,7 @@ test_that("Only a firstonly, no ID, no ROW",{
     
     expect_error(
         expect_warning(
-            res1 <- NMscanData(file=file.lst,check.time = FALSE)
+            res1 <- NMscanData(file=file.lst,check.time = FALSE, quiet=T)
         )
     )
 })
@@ -252,7 +255,7 @@ test_that("FO and row-level output. No ID, no row.",{
 #### merge.by.row = "ifAvailable" or FALSE
     ## Only row-level output returned because cbind.by.filters=F, and firstonly is without ID and row. Warning that firstonly is dropped. Correct. 
 
-    fileRef <- "testReference/NMscanData13.rds"
+    fileRef <- "testReference/NMscanData_13.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr013.lst")
     file.lst <- "testData/nonmem/xgxr013.lst"
@@ -262,7 +265,7 @@ test_that("FO and row-level output. No ID, no row.",{
 
     ## tabs <- NMscanTables(file=file.lst)
     res1 <- expect_warning(
-        NMscanData(file=file.lst,check.time = FALSE)
+        NMscanData(file=file.lst,check.time = FALSE, quiet=T)
     )
     fix.time(res1)
     expect_equal_to_reference(
@@ -271,12 +274,12 @@ test_that("FO and row-level output. No ID, no row.",{
 
     ## merge.by.row=F cannot combine and returns output. OK
     res2 <- expect_warning(
-        NMscanData(file=file.lst,check.time = FALSE,merge.by.row=T)
+        NMscanData(file=file.lst,check.time = FALSE,merge.by.row=T, quiet=T)
     )
 
     ## if we leave use.input out and can only get row level. OK
     res2 <- expect_warning(
-        NMscanData(file=file.lst,check.time = FALSE,use.input=F)
+        NMscanData(file=file.lst,check.time = FALSE,use.input=F, quiet=T)
     )
 
     
@@ -287,7 +290,7 @@ test_that("FO and row-level output. No ID, no row.",{
 ### uses ACCEPT: DOSE.GT.20 explining only 731 rows
 test_that("FO and row-level output. No ID, no row. cbind.by.filters=T",{
     ## row-level output+input returned because cbind.by.filters=T, and firstonly is without ID and row. Correct. 
-    fileRef <- "testReference/NMscanData14.rds"
+    fileRef <- "testReference/NMscanData_14.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr013.lst")
     file.lst <- "testData/nonmem/xgxr013.lst"
@@ -295,7 +298,7 @@ test_that("FO and row-level output. No ID, no row. cbind.by.filters=T",{
     
     ## tabs <- NMscanTables(file=file.lst)
     res1 <- expect_warning(
-        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE)
+        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE, quiet=T)
     )
     fix.time(res1)
     summary(res1)$variables
@@ -326,7 +329,7 @@ test_that("Only a firstonly without ID but with ROW",{
 
     res1 <- expect_error(
                                         #expect_warning(
-        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE)
+        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE, quiet=T)
         ## )
     )
 
@@ -339,7 +342,7 @@ test_that("Only a firstonly without ID but with ROW. Using merge.by.row=TRUE.",{
     ##    NMdataConf(as.fun="data.table")
     ## NMdataConf(as.fun=NULL)
     NMdataConf(reset=TRUE)
-    fileRef <- "testReference/NMscanData15b.rds"
+    fileRef <- "testReference/NMscanData_15b.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr011.lst")
     file.lst <- "testData/nonmem/xgxr011.lst"
@@ -351,7 +354,7 @@ test_that("Only a firstonly without ID but with ROW. Using merge.by.row=TRUE.",{
     ## tabs
 
     res1 <- expect_warning(
-        NMscanData(file=file.lst,col.row="ROW",merge.by.row=TRUE,check.time = FALSE)
+        NMscanData(file=file.lst,col.row="ROW",merge.by.row=TRUE,check.time = FALSE, quiet=T)
     )
     
     fix.time(res1)
@@ -365,7 +368,7 @@ test_that("Only a firstonly without ID but with ROW. Using merge.by.row=TRUE.",{
 
 test_that("recoverRows without a row identifier",{
 
-    fileRef <- "testReference/NMscanData16.rds"
+    fileRef <- "testReference/NMscanData_16.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr004.lst")
     file.lst <- "testData/nonmem/xgxr004.lst"
@@ -375,7 +378,7 @@ test_that("recoverRows without a row identifier",{
 ### notice that DV PRED RES WRES are returned in firstonly. 
     ## tabs <- NMscanTables(file.lst)
     ## tabs
-    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun="data.table",check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun="data.table",check.time = FALSE, quiet=T)
     dim(res1)
     res1[,table(nmout,DOSE)]
     fix.time(res1)
@@ -390,13 +393,13 @@ test_that("recoverRows without a row identifier",{
 test_that("use as.fun to get a data.frame",{
 ### cbind.by.filters is TRUE, so ROW is used to recover firstonly data.
 
-    fileRef <- "testReference/NMscanData17.rds"
+    fileRef <- "testReference/NMscanData_17.rds"
 
     file.lst <- "testData/nonmem/xgxr004.lst"
     NMreadSection(file.lst,section="DATA")
     NMreadSection(file.lst,section="TABLE")
 
-    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun=as.data.frame,check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun=as.data.frame,check.time = FALSE, quiet=T)
     dim(res1)
     class(res1)
     with(res1,table(nmout,DOSE))
@@ -427,7 +430,7 @@ test_that("use as.fun to get a data.frame",{
 test_that("use as.fun to get a tibble",{
 ### cbind.by.filters is TRUE, so ROW is used to recover firstonly data.
 
-    fileRef <- "testReference/NMscanData18.rds"
+    fileRef <- "testReference/NMscanData_18.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr004.lst")
     file.lst <- "testData/nonmem/xgxr004.lst"
@@ -438,7 +441,7 @@ test_that("use as.fun to get a tibble",{
     ## tabs <- NMscanTables(file.lst)
     ## tabs
 
-    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun=tibble::as_tibble,check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row=FALSE,recover.rows = T,as.fun=tibble::as_tibble,check.time = FALSE, quiet=T)
     dim(res1)
     class(res1)
 
@@ -480,7 +483,7 @@ test_that("dir structure with input.txt/output.txt",{
     
     ## filedir.lst <- file.nm("xgxr001dir/output.txt")
     filedir.lst <- "testData/nonmem/xgxr001dir/output.txt"
-    res1dir <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=F)
+    res1dir <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=F, quiet=T)
 
     ## test model names from NMinfo and in result data
     expect_equal(NMinfo(res1dir,"details")$model,"xgxr001dir")
@@ -505,14 +508,14 @@ test_that("input.txt/output.txt - unset modelname",{
     
     ## filedir.lst <- file.nm("xgxr001dir/output.txt")
     filedir.lst <- "testData/nonmem/xgxr001dir/output.txt"
-    res1dir <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=T)
+    res1dir <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=T, quiet=T)
 
     NMdataConf(file.mod="default")
     NMdataConf(modelname=NULL)
     
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr001.lst")
     file.lst <- "testData/nonmem/xgxr001.lst"
-    res1 <- NMscanData(file=file.lst,check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,check.time = FALSE, quiet=T)
 
     ## unNMdata(res1)
     ## unNMdata(res1dir)
@@ -561,7 +564,7 @@ test_that("output.txt, file.mod=identity - NMinfo file.mod=output.txt?",{
     
     ## filedir.lst <- file.nm("xgxr001dir/output.txt")
     filedir.lst <- "testData/nonmem/xgxr001dir/output.txt"
-    res1 <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=F)
+    res1 <- NMscanData(filedir.lst,check.time = FALSE,merge.by.row=F, quiet=T)
 
     expect_equal(basename(NMinfo(res1,"details")$file.lst),"output.txt")
 })
@@ -570,13 +573,13 @@ test_that("output.txt, file.mod=identity - NMinfo file.mod=output.txt?",{
 
 test_that("Duplicate columns in input data",{
     NMdataConf(reset=TRUE)
-    fileRef <- "testReference/NMscanData20.rds"
+    fileRef <- "testReference/NMscanData_20.rds"
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr015.lst")
     file.lst <- "testData/nonmem/xgxr015.lst"
 
     ## debugonce(NMscanData)
     res <- expect_warning(
-        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE)
+        NMscanData(file=file.lst,merge.by.row=FALSE,check.time = FALSE, quiet=T)
     )
     fix.time(res)
     ## names(res$row)
@@ -606,7 +609,7 @@ test_that("Modifying row identifier",{
 
     res <-
         expect_error(
-            NMscanData(file=file.lst,merge.by.row=TRUE,check.time = FALSE)
+            NMscanData(file=file.lst,merge.by.row=TRUE,check.time = FALSE, quiet=T)
         )
 
 })
@@ -617,7 +620,7 @@ test_that("merge.by.row=ifAvailable when available",{
 
     file.lst <- system.file("examples/nonmem/xgxr001.lst" ,package="NMdata")
     
-    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",check.time=FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",check.time=FALSE, quiet=T)
     ## dim(res1)
 
 ### we don't need metadata for this test
@@ -630,13 +633,13 @@ test_that("merge.by.row=ifAvailable when available",{
 
 test_that("merge.by.row=ifAvailable when not available",{
 
-    fileRef <- "testReference/NMscanData22.rds"
+    fileRef <- "testReference/NMscanData_22.rds"
 
     ## file.lst <- NMdata_filepath("examples/nonmem/xgxr004.lst")
     file.lst <- "testData/nonmem/xgxr004.lst"
 
 
-    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",recover.rows = T,as.fun="data.table",check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",recover.rows = T,as.fun="data.table",check.time = FALSE, quiet=T)
     dim(res1)
     res1[,table(nmout,DOSE)]
     fix.time(res1)
@@ -658,7 +661,7 @@ test_that("merge.by.row=ifAvailable when not available",{
 
 test_that("col.row does not exist, but merge.by.row==TRUE",{
 ### col.row does not exist, but merge.by.row==TRUE
-    fileRef <- "testReference/NMscanData22b.rds"
+    fileRef <- "testReference/NMscanData_22b.rds"
     NMdataConf(reset=T)
     NMdataConf(check.time=F)
     file.lst <- system.file("examples/nonmem/xgxr001.lst" ,package="NMdata")
@@ -666,7 +669,7 @@ test_that("col.row does not exist, but merge.by.row==TRUE",{
     ## warning becauses the merge was not possible even though merge.by.row
     res1 <- 
         expect_warning(
-            NMscanData(file=file.lst,col.row="NONEXIST",merge.by.row=TRUE)
+            NMscanData(file=file.lst,col.row="NONEXIST",merge.by.row=TRUE, quiet=T)
         )
     fix.time(res1)
     expect_equal_to_reference(res1,fileRef)
@@ -688,7 +691,7 @@ test_that("col.row is NULL, but merge.by.row==TRUE",{
     
     ## error is that it's not in output. It's not in input either though
     expect_error(
-        res1=NMscanData(file=file.lst,col.row=NULL,merge.by.row=TRUE)
+        res1=NMscanData(file=file.lst,col.row=NULL,merge.by.row=TRUE, quiet=T)
     )
 
     
@@ -697,11 +700,11 @@ test_that("col.row is NULL, but merge.by.row==TRUE",{
 
 test_that("A filter without operator",{
 
-    fileRef <- "testReference/NMscanData23.rds"
+    fileRef <- "testReference/NMscanData_23.rds"
 
     file.lst <- "testData/nonmem/xgxr010.lst"
 
-    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",as.fun="data.table",check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",as.fun="data.table",check.time = FALSE, quiet=T)
     res1[,.N,by=.(DOSE)]
     fix.time(res1)
     
@@ -716,12 +719,12 @@ test_that("Including a redundant output table",{
     NMdataConf(reset=T)
     NMdataConf(as.fun="data.table")
 
-    fileRef <- "testReference/NMscanData24.rds"
+    fileRef <- "testReference/NMscanData_24.rds"
     ## file.lst <- file.nm("xgxr019.lst")
     file.lst <- "testData/nonmem/xgxr019.lst"
 
     ## notice no cols are taken from the redundant table - correct
-    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",as.fun="data.table",check.time = FALSE)
+    res1 <- NMscanData(file=file.lst,merge.by.row="ifAvailable",as.fun="data.table",check.time = FALSE, quiet=T)
     ##     tabs1 <- NMscanTables(file=file.lst,as.fun="data.table",details=T,rep.count=F)
     ##     tabs1$meta
     ## tabs1$data[[4]]
@@ -745,12 +748,12 @@ test_that("redundant output",{
     NMdataConf(file.mod=function(x)sub("\\.lst$",".ctl",x))
     NMdataConf(check.time=FALSE)
 
-    fileRef <- "testReference/NMscanData25.rds"
+    fileRef <- "testReference/NMscanData_25.rds"
     file.lst <- "testData/nonmem/estim_debug.ctl"
 
     ## notice no cols are taken from the redundant table - correct
     res1 <- expect_message(
-        NMscanData(file=file.lst)
+        NMscanData(file=file.lst, quiet=T)
     )
 
 
@@ -794,7 +797,7 @@ if(FALSE){
         NMwriteSection(file.mod,section="data",newlines=data.new)
         
         res1 <- expect_warning(
-            NMscanData(file=file.lst, quiet=F, order.columns = F, merge.by.row=FALSE)
+            NMscanData(file=file.lst, quiet=F, order.columns = F, merge.by.row=FALSE, quiet=T)
         )
         ## dim(res1)'
         
@@ -809,14 +812,14 @@ test_that("$INPUT copy",{
     NMdataConf(check.time=FALSE)
     
     file.lst.1 <- "testData/nonmem/xgxr022.lst"
-    res.1 <- NMscanData(file.lst.1)
+    res.1 <- NMscanData(file.lst.1, quiet=T)
 
     ## NMinfo(res,"input.colname")
     NMinfo(res.1,"input.colnames")
     NMinfo(res.1,"columns")
 
     file.lst.2 <- "testData/nonmem/xgxr001.lst"
-    res.2 <- NMscanData(file.lst.2)
+    res.2 <- NMscanData(file.lst.2, quiet=T)
 
     expect_equal(ncol(res.1)-ncol(res.2),1)
     expect_equal(setdiff(colnames(res.1),colnames(res.2)),c("COMP","EFF0"))
@@ -836,10 +839,10 @@ test_that("only firstonly. Has col.id, no col.row.",{
     NMdataConf(check.time=FALSE)
 
     
-    fileRef <- "testReference/NMscanData27.rds"
+    fileRef <- "testReference/NMscanData_27.rds"
     
     file.lst <- "testData/nonmem/xgxr023.lst"
-    res <- NMscanData(file.lst,quiet=F)
+    res <- NMscanData(file.lst,quiet=TRUE)
     res <- fix.time(res)
 
     expect_equal_to_reference(res,fileRef)
@@ -849,10 +852,10 @@ test_that("only firstonly. Has col.id, no col.row.",{
 
 test_that("Two firstonly, one full-length",{
 
-    fileRef <- "testReference/NMscanData28.rds"
+    fileRef <- "testReference/NMscanData_28.rds"
     file.lst <- "testData/nonmem/xgxr025.lst"
 
-    res <- NMscanData(file=file.lst,check.time=F)
+    res <- NMscanData(file=file.lst,check.time=F, quiet=T)
     res <- fix.time(res)
     ## ref <- readRDS(fileRef)
     
@@ -865,10 +868,10 @@ test_that("Two firstonly, one full-length with rep.count",{
 #### TABLENO is now added to the number of columns taken from the
 #### output table that has TABLENO. Is that what we want? Or +1? +1 is
 #### very complicated for user. Maybe better: if rep.count, it is treated like any other column, but in NMinfo(,"tables") there is a column, hasTABLENO
-    fileRef <- "testReference/NMscanData28b.rds"
+    fileRef <- "testReference/NMscanData_28b.rds"
     file.lst <- "testData/nonmem/xgxr025.lst"
 
-    res <- NMscanData(file=file.lst,check.time=F,rep.count=T)
+    res <- NMscanData(file=file.lst,check.time=F,rep.count=T, quiet=T)
     res <- fix.time(res)
     ## ref <- readRDS(fileRef)
     
@@ -884,9 +887,9 @@ test_that("Input data as character",{
 
     expect_error(NMscanData(file=file.lst,check.time=F))
     
-    res <- NMscanData(file=file.lst,check.time=F,use.rds=F)
+    res <- NMscanData(file=file.lst,check.time=F,use.rds=F, quiet=T)
     sapply(res,class)
-    res <- NMscanData(file=file.lst,check.time=F,use.rds=T,merge.by.row = F)
+    res <- NMscanData(file=file.lst,check.time=F,use.rds=T,merge.by.row = F, quiet=T)
     sapply(res,class)
     
     ## res <- fix.time(res)
@@ -904,7 +907,7 @@ test_that("Input control stream missing",{
 
     fileRef <- "testReference/NMscanData_30.rds"
     file.lst <- "testData/nonmem/xgxr001.lst"
-    res <- NMscanData(file=file.lst,use.input=F)
+    res <- NMscanData(file=file.lst,use.input=F, quiet=T)
     ## check file.mod wasn't used. Notice, merge.by.row is still "ifAvailable" - this was never needed because use.input=FALSE.
     ##    NMinfo(res1a,"details")
     fix.time(res)
@@ -940,7 +943,7 @@ test_that("simulation model with subproblems",{
     ## saveRDS(res.sim,"testData/simulations/NMsimData_xgxr014_testsim1.rds",version=2)
 ##### sim done
     
-    res <- NMscanData("testData/simulations/xgxr014_testsim1.lst",check.time=F)
+    res <- NMscanData("testData/simulations/xgxr014_testsim1.lst",check.time=F, quiet=T)
     
     fix.time(res)
     meta.x <- attr(res,"NMdata")
@@ -960,11 +963,11 @@ test_that("csv vs rds vs fst",{
 
 
     
-    res.csv <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(csv))
+    res.csv <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(csv), quiet=T)
 
-    res.rds <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(rds,csv))
+    res.rds <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(rds,csv), quiet=T)
 
-    res.fst <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(fst,csv))
+    res.fst <- NMscanData(file=file.lst, order.columns = F, merge.by.row=FALSE, check.time = FALSE,formats.read=cc(fst,csv), quiet=T)
 
     res <- dims(res.csv,res.rds,res.fst)
 
